"""CHAPPS

Caching, Highly-Available Postfix Policy Service

In addition to module documentation found here, an introduction and overview of
the project is presented in its README_.  Specific concerns and instructions
about getting it running are discussed in the INSTALLATION_ file.

"""
from ._version import __version__
import chapps.logging

__all__ = [
    "util",
    "config",
    "signals",
    "logging",
    "actions",
    "adapter",
    "policy",
    "spf_policy",
    "outbound",
    "switchboard",
]
